# Generated by Django 4.2.23 on 2025-08-26 12:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('rattingtax', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='corpmonthstat',
            name='closed',
            field=models.BooleanField(default=False, help_text='When true, month is frozen and not recalculated.'),
        ),
    ]
